/**
 * Copyright 1998-2007, CHISEL Group, University of Victoria, Victoria, BC, Canada.
 * All rights reserved.
 */
package ca.uvic.csr.shrimp.gui.ShrimpView;

import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.util.Vector;

import javax.swing.JComboBox;

import ca.uvic.csr.shrimp.DisplayBean.DisplayBean;
import ca.uvic.csr.shrimp.DisplayBean.DisplayConstants;
import ca.uvic.csr.shrimp.SelectorBean.SelectorBean;


/**
 * Displays the label modes for {@link ShrimpView}.
 * Moved from being an inner class of ShrimpView.
 * 
 * @author Chris Callendar
 * @date 26-Oct-06
 */
public class LabelModeComboBox extends JComboBox {
	
	private ItemListener il;
	
	public LabelModeComboBox(Vector modes, final DisplayBean displayBean, final SelectorBean selectorBean) {
		super(modes);
		
        setSelectedItem (displayBean.getDefaultLabelMode());
        setToolTip(displayBean.getDefaultLabelMode());
        setEditable(false);
        
		il = new ItemListener() {
			public void itemStateChanged(ItemEvent e) {
			    if (e.getStateChange() == ItemEvent.SELECTED) {
			    	String labelMode = (String) e.getItem();
					displayBean.setDefaultLabelMode(labelMode);
        			setToolTip(labelMode);
        			// @tag Shrimp(LabelMode) : update the SelectorBean otherwise combobox gets out of sync [author=ccallend;date=18oct05]
        			selectorBean.setSelected(DisplayConstants.LABEL_MODE, displayBean.getDefaultLabelMode());
			    } 
			}
		};
		addItemListener(il);
		
		selectorBean.addPropertyChangeListener(DisplayConstants.LABEL_MODE, new PropertyChangeListener() {
			public void propertyChange(PropertyChangeEvent evt) {
				removeItemListener(il);
				String labelMode = (String) evt.getNewValue();
				setSelectedItem (labelMode);
        		setToolTip(labelMode);
				addItemListener(il);
			}
		});
	}
	
	private void setToolTip(String labelMode) {
		if (labelMode.equals(DisplayConstants.LABEL_MODE_SCALE_BY_NODE_SIZE)) {
			setToolTipText(DisplayConstants.SCALE_BY_NODE_SIZE_LONG_NAME);
		// @tag shrimp(fitToNodeLabelling)
		} else if (labelMode.equals(DisplayConstants.LABEL_MODE_FIT_TO_NODE)){
			setToolTipText(DisplayConstants.FIT_TO_NODE_SIZE_LONG_NAME);
		} else if (labelMode.equals(DisplayConstants.LABEL_MODE_WRAP_TO_NODE)){
			setToolTipText(DisplayConstants.WRAP_TO_NODE_SIZE_LONG_NAME);
		} else if (labelMode.equals(DisplayConstants.LABEL_MODE_SCALE_BY_LEVEL)){
			setToolTipText(DisplayConstants.SCALE_BY_LEVEL_LONG_NAME);
		} else if (labelMode.equals(DisplayConstants.LABEL_MODE_FIXED)){
			setToolTipText(DisplayConstants.FIXED_LONG_NAME);
		} 
	}
	
}
